@@ -14,7 +14,7 @@
 #' * a numeric vector with the loss at each value of lambda
 #' * a numeric value indicating the number of lambda values used
 #' * a numeric value with the predicted outcome (y hat) values at each lambda
-#'
+
 cvf <- function(i, fold, type, cv_args, ...) {
   # save the 'prep' object from the plmm_prep() in cv_plmm
   full_cv_prep <- cv_args$prep
@@ -42,31 +42,35 @@ cvf <- function(i, fold, type, cv_args, ...) {
   if (cv_args$fbm_flag) {
 
     # designate the training set
-    train_X <- bigmemory::deepcopy(full_cv_prep$std_X,
-                                   rows = which(fold!=i),
-                                   type = "double",
-                                   backingfile = paste0("train_fold",i,".bk"),
-                                   descriptorfile = paste0("train_fold",i,".desc"),
-                                   backingpath = bigmemory::dir.name(full_cv_prep$std_X))
-
-    # TODO should these fold-specific data files be created in a tempdir? Then,
-    #   the entire tempdir could be deleted at the end of this function....
+    train_X <- bigmemory::deepcopy(
+      full_cv_prep$std_X,
+      rows = which(fold != i),
+      type = "double",
+      backingfile = paste0("train_fold", i, ".bk"),
+      descriptorfile = paste0("train_fold", i, ".desc"),
+      backingpath = bigmemory::dir.name(full_cv_prep$std_X)
+    )
 
     # create the copy of the training data to be standardized
-    fold_args$std_X <- bigmemory::deepcopy(full_cv_prep$std_X,
-                                           rows = which(fold!=i),
-                                           type = "double",
-                                           backingfile = paste0("std_train_fold",i,".bk"),
-                                           descriptorfile = paste0("std_train_fold",i,".desc"),
-                                           backingpath = bigmemory::dir.name(full_cv_prep$std_X))
+    fold_args$std_X <- bigmemory::deepcopy(
+      full_cv_prep$std_X,
+      rows = which(fold != i),
+      type = "double",
+      backingfile = paste0("std_train_fold", i, ".bk"),
+      descriptorfile = paste0("std_train_fold", i, ".desc"),
+      backingpath = bigmemory::dir.name(full_cv_prep$std_X)
+    )
 
     # re-scale data & check for singularity
-    std_trainX_info <- .Call("big_std",
-                        fold_args$std_X@address,
-                        as.integer(count_cores()),
-                        NULL,
-                        NULL,
-                        PACKAGE = "plmmr")
+    std_trainX_info <- .Call(
+      "big_std",
+      fold_args$std_X@address,
+      as.integer(count_cores()),
+      to_center = TRUE,
+      NULL,
+      NULL,
+      PACKAGE = "plmmr"
+    )
 
     fold_args$std_X@address <- std_trainX_info$std_X
     fold_args$std_X_details$center <- std_trainX_info$std_X_center
@@ -80,7 +84,7 @@ cvf <- function(i, fold, type, cv_args, ...) {
   } else {
 
     # subset training data
-    train_X <- full_cv_prep$std_X[fold!=i, ,drop=FALSE]
+    train_X <- full_cv_prep$std_X[fold != i, , drop = FALSE]
 
     # Note: subsetting the data into test/train sets may cause low variance features
     #   to become constant features in the training data. The following lines address this issue
@@ -93,32 +97,31 @@ cvf <- function(i, fold, type, cv_args, ...) {
     # do not fit a model on these (near) singular features!
     singular <- fold_args$std_X_details$scale < 1e-3
     if (sum(singular) >= 1) fold_args$penalty_factor[singular] <- Inf
-
   }
 
   # subset outcome vector to include outcomes for training data only
-  fold_args$y <- cv_args$y[fold!=i]
+  fold_args$y <- cv_args$y[fold != i]
 
   # center the training outcome
   fold_args$centered_y <- fold_args$y |>
-    scale(scale=FALSE) |>
+    scale(scale = FALSE) |>
     drop()
   # extract test set --------------------------------------
   # this comes from cv prep on full data
-  if (cv_args$fbm_flag){
+  if (cv_args$fbm_flag) {
     test_X <- bigmemory::deepcopy(full_cv_prep$std_X,
-                                  rows = which(fold==i),
+                                  rows = which(fold == i),
                                   type = "double",
-                                  backingfile = paste0("test_fold",i,".bk"),
-                                  descriptorfile = paste0("test_fold",i,".desc"),
+                                  backingfile = paste0("test_fold", i, ".bk"),
+                                  descriptorfile = paste0("test_fold", i, ".desc"),
                                   backingpath = bigmemory::dir.name(full_cv_prep$std_X))
 
   } else {
-    test_X <- full_cv_prep$std_X[fold==i, , drop=FALSE]
+    test_X <- full_cv_prep$std_X[fold == i, , drop = FALSE]
   }
 
   # subset outcome for test set
-  test_y <- y[fold==i]
+  test_y <- y[fold == i]
 
   # decomposition for current fold ------------------------------
   if (cv_args$prep$trace) {
@@ -137,7 +140,7 @@ cvf <- function(i, fold, type, cv_args, ...) {
   # fit a plmm within each fold at each value of lambda
   # lambda stays the same for each fold; comes from the overall fit in cv_plmm()
   if (cv_args$prep$trace) {
-    cat("Fitting model in fold ", i, ":\n")
+    cat("** Fitting model in fold ", i, "\n", sep = "")
   }
 
   fit.i <- plmm_fit(prep = fold_prep,
@@ -148,7 +151,6 @@ cvf <- function(i, fold, type, cv_args, ...) {
                     penalty = fold_args$penalty,
                     gamma = fold_args$gamma,
                     alpha = fold_args$alpha,
-                    eta_star = cv_args$eta_star,
                     lambda_min = fold_args$lambda_min,
                     nlambda = fold_args$nlambda,
                     lambda = fold_args$lambda,
@@ -164,40 +166,41 @@ cvf <- function(i, fold, type, cv_args, ...) {
 
   # prediction ---------------------------------------------------
   # note: predictions are on the scale of the standardized training data
-  if(type == "lp"){
+  if (type == "lp") {
     yhat <- predict_within_cv(fit = format.i,
                               testX = test_X,
-                              type = 'lp',
+                              type = "lp",
                               fbm = cv_args$fbm_flag)
   }
 
-  if (type == 'blup'){
+  if (type == "blup") {
     Sigma_11 <- construct_variance(K = fold_prep$K, eta = fit.i$eta)
-    if (cv_args$fbm_flag){
+    if (cv_args$fbm_flag) {
       # we will need a copy of the testing data that is standardized
       std_test_X <- bigmemory::deepcopy(full_cv_prep$std_X,
-                                    rows = which(fold==i),
-                                    type = "double",
-                                    backingfile = paste0("std_test_fold",i,".bk"),
-                                    descriptorfile = paste0("std_test_fold",i,".desc"),
-                                    backingpath = bigmemory::dir.name(full_cv_prep$std_X))
+                                        rows = which(fold == i),
+                                        type = "double",
+                                        backingfile = paste0("std_test_fold", i, ".bk"),
+                                        descriptorfile = paste0("std_test_fold", i, ".desc"),
+                                        backingpath = bigmemory::dir.name(full_cv_prep$std_X))
 
       # use center/scale values from train_X to standardize test_X
       if (length(singular) >= 1) fold_args$std_X_details$scale[singular] <- 1
       std_test_info <- .Call("big_std",
                              std_test_X@address,
                              as.integer(count_cores()),
+                             tocenter = TRUE,
                              fold_args$std_X_details$center,
                              fold_args$std_X_details$scale,
                              PACKAGE = "plmmr")
       std_test_X@address <- std_test_info$std_X
 
-      const <- (fit.i$eta/ncol(train_X))
-      XXt <- bigalgebra::dgemm(TRANSA = 'N',
-                               TRANSB = 'T',
+      const <- (fit.i$eta / ncol(train_X))
+      XXt <- bigalgebra::dgemm(TRANSA = "N",
+                               TRANSB = "T",
                                A = std_test_X,
                                B = fold_args$std_X)
-      Sigma_21 <- const*XXt
+      Sigma_21 <- const * XXt
       Sigma_21 <- Sigma_21[,] # convert to in-memory matrix
     } else {
       # don't rescale columns that were singular features in std_train_X;
@@ -207,13 +210,13 @@ cvf <- function(i, fold, type, cv_args, ...) {
       std_test_X <- scale(test_X,
                           center = fold_args$std_X_details$center,
                           scale = fold_args$std_X_details$scale)
-      Sigma_21 <- fit.i$eta*(1/ncol(train_X))*tcrossprod(std_test_X,
-                                                         fold_args$std_X)
+      Sigma_21 <- fit.i$eta * (1 / ncol(train_X)) * tcrossprod(std_test_X,
+                                                               fold_args$std_X)
     }
 
     yhat <- predict_within_cv(fit = format.i,
                               testX = test_X,
-                              type = 'blup',
+                              type = "blup",
                               fbm = cv_args$fbm_flag,
                               Sigma_11 = Sigma_11,
                               Sigma_21 = Sigma_21)
@@ -224,12 +227,12 @@ cvf <- function(i, fold, type, cv_args, ...) {
   # delete files created in cross-validation, if data is filebacked
   if (cv_args$fbm_flag) {
     list.files(path = bigmemory::dir.name(full_cv_prep$std_X),
-               pattern = paste0("fold",i),
+               pattern = paste0("fold", i),
                full.names = TRUE) |> file.remove()
     gc() # release the pointer
   }
 
   # return -----------------------------------------------------------------
-  loss <- sapply(1:ncol(yhat), function(ll) plmm_loss(test_y, yhat[,ll]))
-  list(loss=loss, nl=length(fit.i$lambda), yhat=yhat)
+  loss <- sapply(seq_len(ncol(yhat)), function(ll) plmm_loss(test_y, yhat[, ll]))
+  list(loss = loss, nl = length(fit.i$lambda), yhat = yhat)
 }
